#[repr(transparent)]pub struct ForceEvent(pub u32);Expand description
Force Event
Tuple Fields
0: u32Implementations
Sourceimpl ForceEvent
impl ForceEvent
Sourcepub const fn fevtac12ne(&self) -> bool
pub const fn fevtac12ne(&self) -> bool
Force Event Auto Command 12 Not Executed
Sourcepub const fn set_fevtac12ne(&mut self, val: bool)
pub const fn set_fevtac12ne(&mut self, val: bool)
Force Event Auto Command 12 Not Executed
Sourcepub const fn fevtac12toe(&self) -> bool
pub const fn fevtac12toe(&self) -> bool
Force Event Auto Command 12 Time Out Error
Sourcepub const fn set_fevtac12toe(&mut self, val: bool)
pub const fn set_fevtac12toe(&mut self, val: bool)
Force Event Auto Command 12 Time Out Error
Sourcepub const fn fevtac12ce(&self) -> bool
pub const fn fevtac12ce(&self) -> bool
Force Event Auto Command 12 CRC Error
Sourcepub const fn set_fevtac12ce(&mut self, val: bool)
pub const fn set_fevtac12ce(&mut self, val: bool)
Force Event Auto Command 12 CRC Error
Sourcepub const fn fevtac12ebe(&self) -> bool
pub const fn fevtac12ebe(&self) -> bool
Force Event Auto Command 12 End Bit Error
Sourcepub const fn set_fevtac12ebe(&mut self, val: bool)
pub const fn set_fevtac12ebe(&mut self, val: bool)
Force Event Auto Command 12 End Bit Error
Sourcepub const fn fevtac12ie(&self) -> bool
pub const fn fevtac12ie(&self) -> bool
Force Event Auto Command 12 Index Error
Sourcepub const fn set_fevtac12ie(&mut self, val: bool)
pub const fn set_fevtac12ie(&mut self, val: bool)
Force Event Auto Command 12 Index Error
Sourcepub const fn fevtcnibac12e(&self) -> bool
pub const fn fevtcnibac12e(&self) -> bool
Force Event Command Not Executed By Auto Command 12 Error
Sourcepub const fn set_fevtcnibac12e(&mut self, val: bool)
pub const fn set_fevtcnibac12e(&mut self, val: bool)
Force Event Command Not Executed By Auto Command 12 Error
Sourcepub const fn set_fevtctoe(&mut self, val: bool)
pub const fn set_fevtctoe(&mut self, val: bool)
Force Event Command Time Out Error
Sourcepub const fn set_fevtcce(&mut self, val: bool)
pub const fn set_fevtcce(&mut self, val: bool)
Force Event Command CRC Error
Sourcepub const fn set_fevtcebe(&mut self, val: bool)
pub const fn set_fevtcebe(&mut self, val: bool)
Force Event Command End Bit Error
Sourcepub const fn set_fevtcie(&mut self, val: bool)
pub const fn set_fevtcie(&mut self, val: bool)
Force Event Command Index Error
Sourcepub const fn set_fevtdtoe(&mut self, val: bool)
pub const fn set_fevtdtoe(&mut self, val: bool)
Force Event Data Time Out Error
Sourcepub const fn set_fevtdce(&mut self, val: bool)
pub const fn set_fevtdce(&mut self, val: bool)
Force Event Data CRC Error
Sourcepub const fn set_fevtdebe(&mut self, val: bool)
pub const fn set_fevtdebe(&mut self, val: bool)
Force Event Data End Bit Error
Sourcepub const fn set_fevtac12e(&mut self, val: bool)
pub const fn set_fevtac12e(&mut self, val: bool)
Force Event Auto Command 12 Error
Sourcepub const fn set_fevttne(&mut self, val: bool)
pub const fn set_fevttne(&mut self, val: bool)
Force Tuning Error
Sourcepub const fn set_fevtdmae(&mut self, val: bool)
pub const fn set_fevtdmae(&mut self, val: bool)
Force Event DMA Error
Sourcepub const fn set_fevtcint(&mut self, val: bool)
pub const fn set_fevtcint(&mut self, val: bool)
Force Event Card Interrupt